@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.99001';
+$Net::Whois::Raw::Data::VERSION = '2.99002';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -148,7 +148,7 @@ our %servers = qw(
     PRO             whois.nic.pro
     TEL             whois-tel.neustar.biz
     TRAVEL          whois.nic.travel
-    
+
     ACADEMY         whois.donuts.co
     ACCOUNTANTS     whois.donuts.co
     AGENCY          whois.donuts.co
@@ -258,6 +258,7 @@ our %servers = qw(
     SCHULE          whois.donuts.co
     SERVICES        whois.donuts.co
     SHOES           whois.donuts.co
+    SHOPPING        whois.donuts.co
     SINGLES         whois.donuts.co
     SOLAR           whois.donuts.co
     SOLUTIONS       whois.donuts.co
@@ -295,8 +296,10 @@ our %servers = qw(
     CAR             whois.uniregistry.net
     CARS            whois.uniregistry.net
     CHRISTMAS       whois.uniregistry.net
+    GAME            whois.uniregistry.net
     GIFT            whois.uniregistry.net
     GUITARS         whois.uniregistry.net
+    HELP            whois.uniregistry.net
     HIPHOP          whois.uniregistry.net
     JUEGOS          whois.uniregistry.net
     LINK            whois.uniregistry.net
@@ -323,6 +326,7 @@ our %servers = qw(
     MOSCOW          whois.nic.moscow
     ONE             whois.nic.one
     OOO             whois.nic.ooo
+    SHOP            whois.nic.shop
     SRL             whois.nic.srl
     STUDY           whois.nic.study
     TATAR           whois.nic.tatar
@@ -395,6 +399,7 @@ our %servers = qw(
     YOGA            whois-dub.mm-registry.com
 
     FAMILY          whois.rightside.co
+    GAMES           whois.rightside.co
     LIVE            whois.rightside.co
     STUDIO          whois.rightside.co
 
@@ -498,6 +503,7 @@ our %servers = qw(
     SM  whois.ripe.net
     SO  whois.nic.so
     ST  whois.nic.st
+    SX  whois.sx
     TC  whois.adamsnames.tc
     TF  whois.nic.tf
     TH  whois.nic.uk
@@ -735,6 +741,8 @@ our %servers = qw(
     MEX.COM     whois.centralnic.com
     NO.COM      whois.centralnic.com
     QC.COM      whois.centralnic.com
+    RADIO.AM    whois.centralnic.com
+    RADIO.FM    whois.centralnic.com
     RU.COM      whois.centralnic.com
     SA.COM      whois.centralnic.com
     SE.COM      whois.centralnic.com
@@ -781,8 +789,18 @@ our %servers = qw(
     BIZ.NS      whois.biz
     NAME.NS     whois.nic.name
     VIP         whois.nic.vip
-    GAME        whois.nic.game
     PROMO       whois.nic.promo
+
+    NOTLD       whois.iana.org
+);
+
+
+our %default_last_tlds = qw(
+    COM         whois.crsnic.net
+    NET         whois.crsnic.net
+    CC          whois.nic.cc
+    TV          whois.nic.tv
+    JOBS        whois.nic.jobs
 );
 
 
@@ -2698,7 +2716,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.99001
+version 2.99002
 
 =head1 AUTHOR
 
